module.exports = defineTest({
	description: 'determine side effects in ES6 super classes'
});
